# Supporters 

Development of this version of OctoPrint wouldn't have been possible without
[the financial support by the community](https://octoprint.org/support-octoprint/) -
thanks to everyone who contributed!

## Patreon Patrons

  * Andre Bubel
  * Andrew Moorby
  * ANTONIO AUGUSTO DE LIMA PONTES
  * Arnljot Arntsen
  * Boris Hussein
  * Brad Jackson
  * Christian Petropolis
  * Christian Wolf
  * COLLE+McVOY
  * D Brian Kimmel
  * DeltaMaker 3D Printers
  * Dorian Gray
  * E3D BigBox
  * Eric Betts
  * Ernesto Martinez
  * Franziska Kunsmann
  * GadgetAngel
  * George Robles
  * jean-claude migneault
  * Jeff Renfer
  * Jeremiah Avery
  * John Robinson (JRo)
  * Joshua Wills
  * Justin Kaufman
  * Kaile Riser
  * Kale Stedman
  * Kazuhiro Ogura
  * Kyle Menigoz
  * LA 3D Printer Repair
  * Lee Dohm
  * LulzBot®
  * Makespace Madrid
  * Mark Walker
  * Martin Majewski
  * Michael Aumock
  * Miles Flavel
  * Mosaic Manufacturing
  * OMER MEHMET SUTAS
  * Patrick Glyré
  * Patrick McGinnis
  * Prof Yuh Wen Chen
  * Randy C. Will
  * Ranjib Dey
  * Robert Gusek
  * Samer Najia
  * Shawn Lewis
  * Simon Hallam
  * Stefan Krister
  * Sven Mueller
  * Trent Shumay
  * Ulrich Kempken
  * Vladislav Kuzemchik

and 1653 more wonderful people pledging on the [Patreon campaign](https://patreon.com/foosel) or via [Github Sponsors](https://github.com/users/foosel/sponsorship)!
